window.Gleam.initSearch([{"doc":"eventsourcing","title":"eventsourcing","content":"&lt;h1 align=&quot;center&quot;&gt;Eventsourcing&lt;/h1&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  ✨ &lt;strong&gt;Event Sourcing Library for Gleam&lt;/strong&gt; ✨\n&lt;/div&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  A Gleam library for building event-sourced systems.\n&lt;/div&gt;\n\n&lt;br /&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://hex.pm/packages/eventsourcing&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/hexpm/v/eventsourcing&quot;\n      alt=&quot;Available on Hex&quot; /&gt;\n  &lt;/a&gt;\n  &lt;a href=&quot;https://hexdocs.pm/eventsourcing&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/badge/hex-docs-ffaff3&quot;\n      alt=&quot;Documentation&quot; /&gt;\n  &lt;/a&gt;\n&lt;/div&gt;\n\n---\n\n## Table of contents\n\n- [Introduction](#introduction)\n- [Features](#features)\n- [Example](#example)\n  - [Command Handling](#command-handling)\n  - [Event Application](#event-application)\n  - [Snapshot Configuration](#snapshot-configuration)\n  - [Running the Example](#running-the-example)\n- [Philosophy](#philosophy)\n- [Installation](#installation)\n- [Support](#support)\n- [Contributing](#contributing)\n- [License](#license)\n\n## Introduction\n\nEventsourcing is a Gleam library designed to help developers build event-sourced systems. Event sourcing is a pattern where changes to the application&#39;s state are stored as a sequence of events. This library provides a simple, type-safe way to implement event sourcing in your Gleam applications.\n\n## Features\n\n- **Event Sourcing**: Build systems based on the event sourcing pattern.\n- **Event Stores**: Supports multiple event store implementations:\n  - [In-memory Store](https://github.com/renatillas/eventsourcing_inmemory): Simple in-memory event store for development and testing.\n  - [Postgres Store](https://github.com/renatillas/eventsourcing_postgres): Event store implementation using PostgreSQL.\n  - [SQLite Store](https://github.com/renatillas/eventsourcing_sqlite): Event store implementation using SQLite.\n- **Command Handling**: Handle commands and produce events with robust error handling.\n- **Event Application**: Apply events to update aggregates.\n- **Snapshotting**: Optimize aggregate rebuilding with configurable snapshots.\n- **Type-safe Error Handling**: Comprehensive error types and Result-based API.\n\n## Example\n\n### Command Handling\n\n```gleam\nimport eventsourcing\nimport eventsourcing/memory_store\n\npub type BankAccount {\n  BankAccount(balance: Float)\n  UnopenedBankAccount\n}\n\npub type BankAccountCommand {\n  OpenAccount(account_id: String)\n  DepositMoney(amount: Float)\n  WithDrawMoney(amount: Float)\n}\n\npub type BankAccountEvent {\n  AccountOpened(account_id: String)\n  CustomerDepositedCash(amount: Float, balance: Float)\n  CustomerWithdrewCash(amount: Float, balance: Float)\n}\n\npub type BankAccountError {\n  CantDepositNegativeAmount\n  CantOperateOnUnopenedAccount\n  CantWithdrawMoreThanCurrentBalance\n}\n\npub fn handle(\n  bank_account: BankAccount,\n  command: BankAccountCommand,\n) -&gt; Result(List(BankAccountEvent), BankAccountError) {\n  case bank_account, command {\n    UnopenedBankAccount, OpenAccount(account_id) -&gt;\n      Ok([AccountOpened(account_id)])\n    BankAccount(balance), DepositMoney(amount) -&gt; {\n      let balance = balance +. amount\n      case amount &gt;. 0.0 {\n        True -&gt; Ok([CustomerDepositedCash(amount:, balance:)])\n        False -&gt; Error(CantDepositNegativeAmount)\n      }\n    }\n    _, _ -&gt; Error(CantOperateOnUnopenedAccount)\n  }\n}\n```\n\n### Event Application\n\n```gleam\npub fn apply(bank_account: BankAccount, event: BankAccountEvent) {\n  case bank_account, event {\n    UnopenedBankAccount, AccountOpened(_) -&gt; BankAccount(0.0)\n    BankAccount(_), CustomerDepositedCash(_, balance) -&gt; BankAccount(balance:)\n    BankAccount(_), CustomerWithdrewCash(_, balance) -&gt; BankAccount(balance:)\n    _, _ -&gt; panic\n  }\n}\n```\n\n### Snapshot Configuration\n\n```Gleam\n// Enable snapshots every 100 events\nlet event_sourcing = \n  eventsourcing.new(mem_store, [query])\n  |&gt; eventsourcing.with_snapshots(eventsourcing.SnapshotConfig(100))\n\n// Load latest snapshot if available\nlet assert Ok(maybe_snapshot) = eventsourcing.get_latest_snapshot(\n  event_sourcing,\n  &quot;account-123&quot;\n)\n```\n\n### Running the Example\n\n```gleam\npub fn main() {\n  let query = fn(aggregate_id, events) {\n    io.println_error(\n      &quot;Aggregate Bank Account with ID: &quot;\n      &lt;&gt; aggregate_id\n      &lt;&gt; &quot; committed &quot;\n      &lt;&gt; events |&gt; list.length |&gt; int.to_string\n      &lt;&gt; &quot; events.&quot;,\n    )\n  }\n  \n  let event_sourcing = \n    eventsourcing.new(\n      event_store: memory_store.new(),\n      queries: [query],\n      handle: handle,\n      apply: apply,\n      empty_state: UnopenedBankAccount,\n    )\n    \n  case eventsourcing.execute(\n    event_sourcing,\n    &quot;account-123&quot;,\n    OpenAccount(&quot;account-123&quot;),\n  ) {\n    Ok(_) -&gt; io.println(&quot;Account created successfully&quot;)\n    Error(error) -&gt; io.println(&quot;Failed to create account: &quot; &lt;&gt; debug(error))\n  }\n}\n```\n\n### Error Handling\n\nThe library now provides comprehensive error handling through the\nEventSourcingError type:\n\n```Gleam\npub type EventSourcingError(domainerror) {\n  DomainError(domainerror)\n  EventStoreError(String)\n  EntityNotFound\n}\n```\n\nAll operations that might fail return a Result type, making\nerror handling explicit and type-safe.\n\n## Philosophy\n\nEventsourcing is designed to make building event-sourced systems easy and intuitive.\nIt encourages a clear separation between command handling and event application,\nmaking your code more maintainable and testable.\n\n## Installation\n\nEventsourcing is published on [Hex](https://hex.pm/packages/eventsourcing)!\nYou can add it to your Gleam projects from the command line:\n\n```sh\ngleam add eventsourcing\n```\n\n## Support\n\nEventsourcing is built by [Renatillas](https://github.com/renatillas).\nContributions are very welcome!\nIf you&#39;ve spotted a bug, or would like to suggest a feature,\nplease open an issue or a pull request.\n\n## Contributing\n\nContributions are welcome! Please follow these steps:\n\n1. Fork the repository.\n2. Create a new branch (`git checkout -b my-feature-branch`).\n3. Make your changes and commit them (`git commit -m &#39;Add new feature&#39;`).\n4. Push to the branch (`git push origin my-feature-branch`).\n5. Open a pull request.\n\nPlease ensure your code adheres to the project&#39;s coding standards and\nincludes appropriate tests.\n\n## License\n\nThis project is licensed under the MIT License.\nSee the [LICENSE](LICENSE) file for details.\n","url":"index.html"},{"doc":"eventsourcing","title":"Aggregate","content":"pub type Aggregate(entity, command, event, error) {\n  Aggregate(\n    aggregate_id: AggregateId,\n    entity: entity,\n    sequence: Int,\n  )\n}\n Represents the current state of an aggregate in the event sourcing system.\n \n ## Fields\n - `aggregate_id`: Unique identifier for the aggregate\n - `entity`: The current state of the entity\n - `sequence`: The current sequence number of the aggregate\nAggregate(\n  aggregate_id: AggregateId,\n  entity: entity,\n  sequence: Int,\n)\n\n\nSynonyms:\neventsourcing.Aggregate\neventsourcing Aggregate","url":"eventsourcing.html#Aggregate"},{"doc":"eventsourcing","title":"AggregateId","content":"pub type AggregateId =\n  String\n Type representing an aggregate&#39;s unique identifier.\n This is used to identify different aggregates in the event sourcing system.\n\nSynonyms:\neventsourcing.AggregateId\neventsourcing AggregateId","url":"eventsourcing.html#AggregateId"},{"doc":"eventsourcing","title":"EventEnvelop","content":"pub type EventEnvelop(event) {\n  MemoryStoreEventEnvelop(\n    aggregate_id: AggregateId,\n    sequence: Int,\n    payload: event,\n    metadata: List(#(String, String)),\n  )\n  SerializedEventEnvelop(\n    aggregate_id: AggregateId,\n    sequence: Int,\n    payload: event,\n    metadata: List(#(String, String)),\n    event_type: String,\n    event_version: String,\n    aggregate_type: String,\n  )\n}\n Wrapper around domain events that includes metadata and sequencing information.\n Used by Event Stores to persist and retrieve events.\n \n ## Variants\n - `MemoryStoreEventEnvelop`: Used for in-memory event storage\n - `SerializedEventEnvelop`: Used for persistent storage with serialization support\nMemoryStoreEventEnvelop(\n  aggregate_id: AggregateId,\n  sequence: Int,\n  payload: event,\n  metadata: List(#(String, String)),\n)\n\n\nSerializedEventEnvelop(\n  aggregate_id: AggregateId,\n  sequence: Int,\n  payload: event,\n  metadata: List(#(String, String)),\n  event_type: String,\n  event_version: String,\n  aggregate_type: String,\n)\n\n\nSynonyms:\neventsourcing.EventEnvelop\neventsourcing EventEnvelop","url":"eventsourcing.html#EventEnvelop"},{"doc":"eventsourcing","title":"EventSourcing","content":"pub opaque type EventSourcing(\n  eventstore,\n  entity,\n  command,\n  event,\n  error,\n  transaction_handle,\n)\n The main record of the library. \n It holds everything together and serves as a reference point \n for other functions such as execute, load_aggregate_entity, and load_events\n\nSynonyms:\neventsourcing.EventSourcing\neventsourcing EventSourcing","url":"eventsourcing.html#EventSourcing"},{"doc":"eventsourcing","title":"EventSourcingError","content":"pub type EventSourcingError(domainerror) {\n  DomainError(domainerror)\n  EventStoreError(String)\n  EntityNotFound\n  TransactionFailed\n  TransactionRolledBack\n}\n Represents errors that can occur in the event sourcing system.\n \n ## Variants\n - `DomainError`: Domain-specific errors from command handling\n - `EventStoreError`: Errors related to event storage operations\n - `EntityNotFound`: When attempting to load a non-existent aggregate\nDomainError(domainerror)\n\n\nEventStoreError(String)\n\n\nEntityNotFound\n\n\nTransactionFailed\n\n\nTransactionRolledBack\n\n\nSynonyms:\neventsourcing.EventSourcingError\neventsourcing EventSourcingError","url":"eventsourcing.html#EventSourcingError"},{"doc":"eventsourcing","title":"EventStore","content":"pub type EventStore(\n  eventstore,\n  entity,\n  command,\n  event,\n  error,\n  transaction_handle,\n) {\n  EventStore(\n    execute_transaction: fn(\n      fn(transaction_handle) -&gt;\n        Result(Nil, EventSourcingError(error)),\n    ) -&gt;\n      Result(Nil, EventSourcingError(error)),\n    load_aggregate_transaction: fn(\n      fn(transaction_handle) -&gt;\n        Result(\n          Aggregate(entity, command, event, error),\n          EventSourcingError(error),\n        ),\n    ) -&gt;\n      Result(\n        Aggregate(entity, command, event, error),\n        EventSourcingError(error),\n      ),\n    load_events_transaction: fn(\n      fn(transaction_handle) -&gt;\n        Result(\n          List(EventEnvelop(event)),\n          EventSourcingError(error),\n        ),\n    ) -&gt;\n      Result(\n        List(EventEnvelop(event)),\n        EventSourcingError(error),\n      ),\n    get_latest_snapshot_transaction: fn(\n      fn(transaction_handle) -&gt;\n        Result(\n          Option(Snapshot(entity)),\n          EventSourcingError(error),\n        ),\n    ) -&gt;\n      Result(Option(Snapshot(entity)), EventSourcingError(error)),\n    commit_events: fn(\n      transaction_handle,\n      Aggregate(entity, command, event, error),\n      List(event),\n      List(#(String, String)),\n    ) -&gt;\n      Result(\n        #(List(EventEnvelop(event)), Int),\n        EventSourcingError(error),\n      ),\n    load_events: fn(\n      eventstore,\n      transaction_handle,\n      AggregateId,\n      Int,\n    ) -&gt;\n      Result(\n        List(EventEnvelop(event)),\n        EventSourcingError(error),\n      ),\n    load_snapshot: fn(transaction_handle, AggregateId) -&gt;\n      Result(Option(Snapshot(entity)), EventSourcingError(error)),\n    save_snapshot: fn(transaction_handle, Snapshot(entity)) -&gt;\n      Result(Nil, EventSourcingError(error)),\n    eventstore: eventstore,\n  )\n}\n The main type of the event sourcing system that coordinates all operations.\n \n ## Fields\n - `event_store`: The storage implementation for events and snapshots\n - `queries`: List of query handlers to process events\n - `handle`: Command handler function\n - `apply`: Event application function\n - `empty_state`: Initial state for new aggregates\n - `snapshot_config`: Optional configuration for snapshot creation\nEventStore(\n  execute_transaction: fn(\n    fn(transaction_handle) -&gt;\n      Result(Nil, EventSourcingError(error)),\n  ) -&gt;\n    Result(Nil, EventSourcingError(error)),\n  load_aggregate_transaction: fn(\n    fn(transaction_handle) -&gt;\n      Result(\n        Aggregate(entity, command, event, error),\n        EventSourcingError(error),\n      ),\n  ) -&gt;\n    Result(\n      Aggregate(entity, command, event, error),\n      EventSourcingError(error),\n    ),\n  load_events_transaction: fn(\n    fn(transaction_handle) -&gt;\n      Result(\n        List(EventEnvelop(event)),\n        EventSourcingError(error),\n      ),\n  ) -&gt;\n    Result(List(EventEnvelop(event)), EventSourcingError(error)),\n  get_latest_snapshot_transaction: fn(\n    fn(transaction_handle) -&gt;\n      Result(Option(Snapshot(entity)), EventSourcingError(error)),\n  ) -&gt;\n    Result(Option(Snapshot(entity)), EventSourcingError(error)),\n  commit_events: fn(\n    transaction_handle,\n    Aggregate(entity, command, event, error),\n    List(event),\n    List(#(String, String)),\n  ) -&gt;\n    Result(\n      #(List(EventEnvelop(event)), Int),\n      EventSourcingError(error),\n    ),\n  load_events: fn(\n    eventstore,\n    transaction_handle,\n    AggregateId,\n    Int,\n  ) -&gt;\n    Result(List(EventEnvelop(event)), EventSourcingError(error)),\n  load_snapshot: fn(transaction_handle, AggregateId) -&gt;\n    Result(Option(Snapshot(entity)), EventSourcingError(error)),\n  save_snapshot: fn(transaction_handle, Snapshot(entity)) -&gt;\n    Result(Nil, EventSourcingError(error)),\n  eventstore: eventstore,\n)\n\n\nSynonyms:\neventsourcing.EventStore\neventsourcing EventStore","url":"eventsourcing.html#EventStore"},{"doc":"eventsourcing","title":"Snapshot","content":"pub type Snapshot(entity) {\n  Snapshot(\n    aggregate_id: AggregateId,\n    entity: entity,\n    sequence: Int,\n    timestamp: Int,\n  )\n}\n Represents a snapshot of an aggregate&#39;s state at a specific point in time.\n Snapshots are used to optimize aggregate rebuilding by providing a starting point.\n \n ## Fields\n - `aggregate_id`: The aggregate this snapshot belongs to\n - `entity`: The state of the entity at the time of snapshot\n - `sequence`: The sequence number at which this snapshot was taken\n - `timestamp`: Unix timestamp when the snapshot was created\nSnapshot(\n  aggregate_id: AggregateId,\n  entity: entity,\n  sequence: Int,\n  timestamp: Int,\n)\n\n\nSynonyms:\neventsourcing.Snapshot\neventsourcing Snapshot","url":"eventsourcing.html#Snapshot"},{"doc":"eventsourcing","title":"SnapshotConfig","content":"pub type SnapshotConfig {\n  SnapshotConfig(snapshot_frequency: Int)\n}\n Configuration for snapshot creation behavior.\n \n ## Fields\n - `snapshot_frequency`: Number of events after which a new snapshot should be created\nSnapshotConfig(snapshot_frequency: Int)\n\n\nSynonyms:\neventsourcing.SnapshotConfig\neventsourcing SnapshotConfig","url":"eventsourcing.html#SnapshotConfig"},{"doc":"eventsourcing","title":"add_query","content":"pub fn add_query(\n  eventsourcing eventsourcing: EventSourcing(a, b, c, d, e, f),\n  query query: fn(String, List(EventEnvelop(d))) -&gt; Nil,\n) -&gt; EventSourcing(a, b, c, d, e, f)\n Add a query to the EventSourcing instance.\n\n Queries are functions that run when events are committed.\n They can be used for things like updating read models or sending notifications.\nSynonyms:\neventsourcing.add_query\neventsourcing add_query","url":"eventsourcing.html#add_query"},{"doc":"eventsourcing","title":"execute","content":"pub fn execute(\n  event_sourcing event_sourcing: EventSourcing(a, b, c, d, e, f),\n  aggregate_id aggregate_id: String,\n  command command: c,\n) -&gt; Result(Nil, EventSourcingError(e))\n Executes a command against an aggregate.\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance\n - `aggregate_id`: ID of the aggregate to execute command against\n - `command`: The command to execute\n \n ## Returns\n Ok(Nil) if successful, or an error if command handling fails\nSynonyms:\neventsourcing.execute\neventsourcing execute","url":"eventsourcing.html#execute"},{"doc":"eventsourcing","title":"execute_with_metadata","content":"pub fn execute_with_metadata(\n  event_sourcing event_sourcing: EventSourcing(a, b, c, d, e, f),\n  aggregate_id aggregate_id: String,\n  command command: c,\n  metadata metadata: List(#(String, String)),\n) -&gt; Result(Nil, EventSourcingError(e))\n Executes a command with additional metadata.\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance\n - `aggregate_id`: ID of the aggregate to execute command against\n - `command`: The command to execute\n - `metadata`: Additional metadata to store with generated events\n \n ## Returns\n Ok(Nil) if successful, or an error if command handling fails\nSynonyms:\neventsourcing.execute_with_metadata\neventsourcing execute_with_metadata","url":"eventsourcing.html#execute_with_metadata"},{"doc":"eventsourcing","title":"get_latest_snapshot","content":"pub fn get_latest_snapshot(\n  event_sourcing event_sourcing: EventSourcing(a, b, c, d, e, f),\n  aggregate_id aggregate_id: String,\n) -&gt; Result(Option(Snapshot(b)), EventSourcingError(e))\n Retrieves the most recent snapshot for an aggregate if it exists.\n \n This function attempts to load the latest snapshot for an aggregate, which can be\n used as a starting point for rebuilding aggregate state without replaying all events\n from the beginning.\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance\n - `aggregate_id`: ID of the aggregate to get the snapshot for\n \n ## Returns\n A Result containing:\n - Ok(Some(Snapshot)): The latest snapshot if one exists\n - Ok(None): If no snapshot exists for the aggregate\n - Error(EventSourcingError): If snapshot retrieval fails\n \n ## Example\n \n let assert Ok(maybe_snapshot) = get_latest_snapshot(event_sourcing, &quot;account-123&quot;)\n case maybe_snapshot {\n   Some(snapshot) -&gt; // Use snapshot as starting point\n   None -&gt; // No snapshot exists, start from initial state\n }\n \nSynonyms:\neventsourcing.get_latest_snapshot\neventsourcing get_latest_snapshot","url":"eventsourcing.html#get_latest_snapshot"},{"doc":"eventsourcing","title":"load_aggregate","content":"pub fn load_aggregate(\n  event_sourcing event_sourcing: EventSourcing(a, b, c, d, e, f),\n  aggregate_id aggregate_id: String,\n) -&gt; Result(Aggregate(b, c, d, e), EventSourcingError(e))\n Loads the current state of an aggregate.\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance\n - `aggregate_id`: ID of the aggregate to load\n \n ## Returns\n The current state of the aggregate, or an error if loading fails\nSynonyms:\neventsourcing.load_aggregate\neventsourcing load_aggregate","url":"eventsourcing.html#load_aggregate"},{"doc":"eventsourcing","title":"load_events","content":"pub fn load_events(\n  event_sourcing event_sourcing: EventSourcing(a, b, c, d, e, f),\n  aggregate_id aggregate_id: String,\n) -&gt; Result(List(EventEnvelop(d)), EventSourcingError(e))\n Loads all events for an aggregate from a specified sequence number.\n \n This function retrieves all events for an aggregate starting from a given sequence number,\n allowing for partial event stream loading and event replay from a specific point in time.\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance\n - `aggregate_id`: ID of the aggregate whose events should be loaded\n - `start_from`: The sequence number to start loading events from\n \n ## Returns\n A Result containing:\n - Ok(List(EventEnvelop(event))): List of events if successful\n - Error(EventSourcingError): If loading fails\n \n ## Example\n \n let assert Ok(events) = load_events(event_sourcing, &quot;account-123&quot;, 5)\n // events will contain all events for account-123 starting from sequence 5\n \nSynonyms:\neventsourcing.load_events\neventsourcing load_events","url":"eventsourcing.html#load_events"},{"doc":"eventsourcing","title":"new","content":"pub fn new(\n  event_store event_store: EventStore(a, b, c, d, e, f),\n  queries queries: List(fn(String, List(EventEnvelop(d))) -&gt; Nil),\n  handle handle: fn(b, c) -&gt; Result(List(d), e),\n  apply apply: fn(b, d) -&gt; b,\n  empty_state empty_state: b,\n) -&gt; EventSourcing(a, b, c, d, e, f)\n Creates a new EventSourcing instance with the provided configuration.\n \n ## Arguments\n - `event_store`: The storage implementation to use\n - `queries`: List of query handlers to process events\n - `handle`: Function to handle commands\n - `apply`: Function to apply events\n - `empty_state`: Initial state for new aggregates\n \n ## Returns\n A new EventSourcing instance without snapshot support\nSynonyms:\neventsourcing.new\neventsourcing new","url":"eventsourcing.html#new"},{"doc":"eventsourcing","title":"with_snapshots","content":"pub fn with_snapshots(\n  event_sourcing: EventSourcing(a, b, c, d, e, f),\n  config: SnapshotConfig,\n) -&gt; EventSourcing(a, b, c, d, e, f)\n \n ## Arguments\n - `event_sourcing`: The EventSourcing instance to modify\n - `config`: Snapshot configuration specifying creation frequency\n \n ## Returns\n A new EventSourcing instance with snapshot support enabled\nSynonyms:\neventsourcing.with_snapshots\neventsourcing with_snapshots","url":"eventsourcing.html#with_snapshots"},{"doc":"eventsourcing","title":"eventsourcing","content":"","url":"eventsourcing.html"},{"doc":"eventsourcing/memory_store","title":"MemoryStore","content":"pub opaque type MemoryStore(entity, command, event, error)\n\n\nSynonyms:\neventsourcing/memory_store.MemoryStore\neventsourcing/memory_store MemoryStore","url":"eventsourcing/memory_store.html#MemoryStore"},{"doc":"eventsourcing/memory_store","title":"new","content":"pub fn new() -&gt; EventStore(\n  MemoryStore(a, b, c, d),\n  a,\n  b,\n  c,\n  d,\n  MemoryStore(a, b, c, d),\n)\n Create a new memory store record.\nSynonyms:\neventsourcing/memory_store.new\neventsourcing/memory_store new","url":"eventsourcing/memory_store.html#new"},{"doc":"eventsourcing/memory_store","title":"eventsourcing/memory_store","content":"","url":"eventsourcing/memory_store.html"}]);